"use client";
import { motion } from "framer-motion";
import BtnPrimary from "@/components/BtnPrimary";
import { useState } from "react";

export default function Box() {
    // Add state management
    const [formData, setFormData] = useState({
        name: "",
        email: "",
        subject: "",
        message: "",
    });
    const [buttonText, setButtonText] = useState("Submit Form");

    // Handle form submission
    const handleSubmit = () => {
        // Check if all fields are filled
        if (!formData.name || !formData.email || !formData.subject || !formData.message) {
            alert("Please fill in all fields");
            return;
        }

        // Wait 1 second before changing text
        setTimeout(() => {
            setButtonText("Form Submitted");

            // Reset form after 2 seconds of showing "Form Submitted"
            setTimeout(() => {
                setButtonText("Submit Form");
                setFormData({
                    name: "",
                    email: "",
                    subject: "",
                    message: "",
                });
            }, 2000);
        }, 1000);
    };

    return (
        <motion.div
            initial={{
                y: 25,
                opacity: 0,
            }}
            whileInView={{
                y: 0,
                opacity: 1,
            }}
            viewport={{
                once: true,
            }}
            className="relative p-5 border border-white/5 bg-[#0E1618]/10 backdrop-blur-sm"
        >
            <h3 className="mb-1 font-medium uppercase text-[#0CE77E]">Reach Out to Team Vertex</h3>

            <p className="mb-4 text-sm text-white/75">Our support team is available to assist you</p>

            <div className="py-4 border-t border-[#0CE77E]/25 grid grid-cols-[360px_auto] gap-16 items-center">
                <div className="flex items-center gap-3.5">
                    <p className="text-sm uppercase text-white">Your name</p>

                    <div className="relative flex-1 h-[36px] border border-white/5 bg-[#0CE77E]/10 flex items-center">
                        <input
                            type="text"
                            value={formData.name}
                            onChange={(e) => setFormData((prev) => ({ ...prev, name: e.target.value }))}
                            className="w-full px-3.5 bg-transparent text-sm uppercase text-[#0CE77E] placeholder:text-[#0CE77E]/25"
                            placeholder="Enter your name"
                        />

                        <span className="absolute -top-px -left-px group-hover:opacity-0 duration-200">
                            <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M1 0V4.5" stroke="#0CE77E" />
                                <path d="M5.5 0.5L1 0.5" stroke="#0CE77E" />
                            </svg>
                        </span>

                        <span className="absolute -bottom-px -left-px group-hover:opacity-0 duration-200">
                            <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M1 4.5V0" stroke="#0CE77E" />
                                <path d="M5.5 4L1 4" stroke="#0CE77E" />
                            </svg>
                        </span>

                        <span className="absolute -top-px -right-px group-hover:opacity-0 duration-200">
                            <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M5 0V4.5" stroke="#0CE77E" />
                                <path d="M0.5 0.5L5 0.5" stroke="#0CE77E" />
                            </svg>
                        </span>

                        <span className="absolute -bottom-px -right-px group-hover:opacity-0 duration-200">
                            <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M5 4.5V0" stroke="#0CE77E" />
                                <path d="M0.5 4L5 4" stroke="#0CE77E" />
                            </svg>
                        </span>
                    </div>
                </div>

                <div className="flex items-center gap-3.5">
                    <p className="text-sm uppercase text-white">Your email address</p>

                    <div className="relative flex-1 h-[36px] border border-white/5 bg-[#0CE77E]/10 flex items-center">
                        <input
                            type="text"
                            value={formData.email}
                            onChange={(e) => setFormData((prev) => ({ ...prev, email: e.target.value }))}
                            className="w-full px-3.5 bg-transparent text-sm uppercase text-[#0CE77E] placeholder:text-[#0CE77E]/25"
                            placeholder="Enter your email"
                        />

                        <span className="absolute -top-px -left-px group-hover:opacity-0 duration-200">
                            <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M1 0V4.5" stroke="#0CE77E" />
                                <path d="M5.5 0.5L1 0.5" stroke="#0CE77E" />
                            </svg>
                        </span>

                        <span className="absolute -bottom-px -left-px group-hover:opacity-0 duration-200">
                            <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M1 4.5V0" stroke="#0CE77E" />
                                <path d="M5.5 4L1 4" stroke="#0CE77E" />
                            </svg>
                        </span>

                        <span className="absolute -top-px -right-px group-hover:opacity-0 duration-200">
                            <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M5 0V4.5" stroke="#0CE77E" />
                                <path d="M0.5 0.5L5 0.5" stroke="#0CE77E" />
                            </svg>
                        </span>

                        <span className="absolute -bottom-px -right-px group-hover:opacity-0 duration-200">
                            <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M5 4.5V0" stroke="#0CE77E" />
                                <path d="M0.5 4L5 4" stroke="#0CE77E" />
                            </svg>
                        </span>
                    </div>
                </div>
            </div>

            <div className="py-4 border-t border-[#0CE77E]/25">
                <div className="flex items-center gap-3.5">
                    <p className="min-w-[75px] text-sm uppercase text-white">Subject</p>

                    <div className="relative flex-1 h-[36px] border border-white/5 bg-[#0CE77E]/10 flex items-center">
                        <input
                            type="text"
                            value={formData.subject}
                            onChange={(e) => setFormData((prev) => ({ ...prev, subject: e.target.value }))}
                            className="w-full px-3.5 bg-transparent text-sm uppercase text-[#0CE77E] placeholder:text-[#0CE77E]/25"
                            placeholder="I am facing issue with ..."
                        />

                        <span className="absolute -top-px -left-px group-hover:opacity-0 duration-200">
                            <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M1 0V4.5" stroke="#0CE77E" />
                                <path d="M5.5 0.5L1 0.5" stroke="#0CE77E" />
                            </svg>
                        </span>

                        <span className="absolute -bottom-px -left-px group-hover:opacity-0 duration-200">
                            <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M1 4.5V0" stroke="#0CE77E" />
                                <path d="M5.5 4L1 4" stroke="#0CE77E" />
                            </svg>
                        </span>

                        <span className="absolute -top-px -right-px group-hover:opacity-0 duration-200">
                            <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M5 0V4.5" stroke="#0CE77E" />
                                <path d="M0.5 0.5L5 0.5" stroke="#0CE77E" />
                            </svg>
                        </span>

                        <span className="absolute -bottom-px -right-px group-hover:opacity-0 duration-200">
                            <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M5 4.5V0" stroke="#0CE77E" />
                                <path d="M0.5 4L5 4" stroke="#0CE77E" />
                            </svg>
                        </span>
                    </div>
                </div>
            </div>

            <div className="py-4 border-t border-[#0CE77E]/25">
                <div className="flex items-start gap-3.5">
                    <p className="min-w-[75px] text-sm uppercase text-white">Message</p>

                    <div className="relative flex-1 h-[165px] border border-white/5 bg-[#0CE77E]/10">
                        <textarea
                            value={formData.message}
                            onChange={(e) => setFormData((prev) => ({ ...prev, message: e.target.value }))}
                            className="w-full h-[165px] resize-none p-3.5 bg-transparent text-sm uppercase text-[#0CE77E] placeholder:text-[#0CE77E]/25"
                            placeholder="Explain your problem in brief"
                        ></textarea>

                        <span className="absolute -top-px -left-px group-hover:opacity-0 duration-200">
                            <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M1 0V4.5" stroke="#0CE77E" />
                                <path d="M5.5 0.5L1 0.5" stroke="#0CE77E" />
                            </svg>
                        </span>

                        <span className="absolute -bottom-px -left-px group-hover:opacity-0 duration-200">
                            <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M1 4.5V0" stroke="#0CE77E" />
                                <path d="M5.5 4L1 4" stroke="#0CE77E" />
                            </svg>
                        </span>

                        <span className="absolute -top-px -right-px group-hover:opacity-0 duration-200">
                            <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M5 0V4.5" stroke="#0CE77E" />
                                <path d="M0.5 0.5L5 0.5" stroke="#0CE77E" />
                            </svg>
                        </span>

                        <span className="absolute -bottom-px -right-px group-hover:opacity-0 duration-200">
                            <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M5 4.5V0" stroke="#0CE77E" />
                                <path d="M0.5 4L5 4" stroke="#0CE77E" />
                            </svg>
                        </span>
                    </div>
                </div>
            </div>

            <div className="pt-4 border-t border-[#0CE77E]/25">
                <div className="w-[260px]" onClick={handleSubmit}>
                    <BtnPrimary text={buttonText} />
                </div>
            </div>

            <span className="absolute -top-px -left-px group-hover:opacity-0 duration-200">
                <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path d="M1 0V4.5" stroke="#0CE77E" />
                    <path d="M5.5 0.5L1 0.5" stroke="#0CE77E" />
                </svg>
            </span>

            <span className="absolute -bottom-px -left-px group-hover:opacity-0 duration-200">
                <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path d="M1 4.5V0" stroke="#0CE77E" />
                    <path d="M5.5 4L1 4" stroke="#0CE77E" />
                </svg>
            </span>

            <span className="absolute -top-px -right-px group-hover:opacity-0 duration-200">
                <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path d="M5 0V4.5" stroke="#0CE77E" />
                    <path d="M0.5 0.5L5 0.5" stroke="#0CE77E" />
                </svg>
            </span>

            <span className="absolute -bottom-px -right-px group-hover:opacity-0 duration-200">
                <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path d="M5 4.5V0" stroke="#0CE77E" />
                    <path d="M0.5 4L5 4" stroke="#0CE77E" />
                </svg>
            </span>
        </motion.div>
    );
}
