"use client";
import { Radar } from "react-chartjs-2";
import {
  Chart as ChartJS,
  RadialLinearScale,
  PointElement,
  LineElement,
  Filler,
  Tooltip,
  Legend,
} from "chart.js";
ChartJS.register(
  RadialLinearScale,
  PointElement,
  LineElement,
  Filler,
  Tooltip,
  Legend
);
import { motion } from "framer-motion";

export default function Statistics() {
  const data = {
    labels: [
      "Cluster Utilization",
      "Power Draw",
      "NVENC",
      "PCIe Throughput",
      "GPU Utilization",
      "ECC Errors",
      "Avg. Temp",
    ],
    datasets: [
      {
        label: "Performance Metrics",
        data: [140, 120, 120, 60, 100, 120, 120],
        backgroundColor: "rgba(11, 231, 126, 0.2)",
        borderColor: "rgba(11, 231, 126, 1)",
        borderWidth: 2,
        pointBackgroundColor: "rgba(11, 231, 126, 1)",
        pointBorderColor: "rgba(0, 0, 0, 1)",
        pointHoverRadius: 5,
      },
    ],
  };

  const options = {
    responsive: true,
    plugins: {
      tooltip: {
        enabled: true,
        backgroundColor: "rgba(0, 0, 0, 1)",
        titleColor: "rgba(11, 231, 126, 1)",
        bodyColor: "rgba(255, 255, 255, 1)",
      },
      legend: {
        display: false,
      },
    },
    scales: {
      r: {
        ticks: {
          display: true,
          color: "rgba(11, 231, 126, 0.7)",
          backdropColor: "transparent",
        },
        grid: {
          color: "rgba(11, 231, 126, 0.3)",
        },
        angleLines: {
          color: "rgba(11, 231, 126, 0.5)",
        },
        pointLabels: {
          color: "rgba(11, 231, 126, 0.7)",
          font: {
            size: 12,
          },
        },
      },
    },
  };

  return (
    <motion.div
      initial={{
        y: 25,
        opacity: 0,
      }}
      whileInView={{
        y: 0,
        opacity: 1,
      }}
      transition={{
        delay: 1,
      }}
      viewport={{
        once: true,
      }}
      className="relative p-5 border border-white/5 bg-[#0E1618]/10 backdrop-blur-sm"
    >
      <h3 className="mb-1 font-medium uppercase text-[#0CE77E]">
        Resource Statistics
      </h3>

      <p className="mb-4 text-sm text-white/75">
        How the GPU’s resources are being utilized
      </p>

      <div className="flex justify-center">
        <div
          style={{
            width: "380px",
            height: "380px",
          }}
        >
          <Radar data={data} options={options} />
        </div>
      </div>

      <span className="absolute -top-px -left-px group-hover:opacity-0 duration-200">
        <svg
          width="6"
          height="5"
          viewBox="0 0 6 5"
          fill="none"
          xmlns="http://www.w3.org/2000/svg"
        >
          <path d="M1 0V4.5" stroke="#0CE77E" />
          <path d="M5.5 0.5L1 0.5" stroke="#0CE77E" />
        </svg>
      </span>

      <span className="absolute -bottom-px -left-px group-hover:opacity-0 duration-200">
        <svg
          width="6"
          height="5"
          viewBox="0 0 6 5"
          fill="none"
          xmlns="http://www.w3.org/2000/svg"
        >
          <path d="M1 4.5V0" stroke="#0CE77E" />
          <path d="M5.5 4L1 4" stroke="#0CE77E" />
        </svg>
      </span>

      <span className="absolute -top-px -right-px group-hover:opacity-0 duration-200">
        <svg
          width="6"
          height="5"
          viewBox="0 0 6 5"
          fill="none"
          xmlns="http://www.w3.org/2000/svg"
        >
          <path d="M5 0V4.5" stroke="#0CE77E" />
          <path d="M0.5 0.5L5 0.5" stroke="#0CE77E" />
        </svg>
      </span>

      <span className="absolute -bottom-px -right-px group-hover:opacity-0 duration-200">
        <svg
          width="6"
          height="5"
          viewBox="0 0 6 5"
          fill="none"
          xmlns="http://www.w3.org/2000/svg"
        >
          <path d="M5 4.5V0" stroke="#0CE77E" />
          <path d="M0.5 4L5 4" stroke="#0CE77E" />
        </svg>
      </span>
    </motion.div>
  );
}
